#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// Highlight bar if it is the narrowest.
    /// </summary>
    [Description("Highlight bar if it is the narrowest.")]
    public class AARCNR10 : Indicator
    {
        //#region Variables
        // Wizard generated variables
            private int period = 10; // Default setting for Period
			private int barcounter = 0;
			private string nr10text = @"nr10text"; // Default setting for nr10text text
			private Color nr12color = Color.GreenYellow;
			
			private int seperation = 40;  //Variable to offset markers.
			private bool wordingon = true;
			private bool zstrategyuse = false;
		
        // User defined variables (add any user defined variables below)
        //#endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
            //Add(new Plot(Color.FromKnownColor(KnownColor.Orange), PlotStyle.Line, "Plot0"));
			VendorLicense("RaefonTrading", "AARCNR10", "raefontrading.com", "info@raefontrading.com");
            CalculateOnBarClose	= true;
            Overlay				= true;
            PriceTypeSupported	= false;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        { 
			if (zstrategyuse == true){Value.Set(0);}
            // Do not calculate if we don't have enough bars 
			if (CurrentBar < Period) return;
 			if (FirstTickOfBar)
				barcounter++;
			// Get a sum of prices over the specified period 
			double sum = 0; 
			int nrbar = 0;
			for (int barsAgo = 0; barsAgo < Period; barsAgo++) 
			{ 
				if ( Range()[barsAgo] <= Range()[0] )
				{
					nrbar = barsAgo;
				}
			}
			if (nrbar==0)
			{
				if (EMA(1)[0] < EMA(4)[0])
				{DrawDot("AARCNR10"+barcounter.ToString(), true, 0, Low[0] - seperation* TickSize, nr12color);
					if (wordingon == true){DrawText("nr10text"+ CurrentBar, nr10text, 0, Low[0] + -(seperation+5) *TickSize, Color.Black);}
				if (zstrategyuse == true){Value.Set(11);}}
				
				
				if (EMA(1)[0] > EMA(4)[0])
				 {DrawDot("AARCNR10"+barcounter.ToString(), true, 0, High[0] + seperation* TickSize, nr12color);
					if (wordingon == true){DrawText("nr10text"+ CurrentBar, nr10text, 0, High[0] + (seperation+5) *TickSize, Color.Black);}
				if (zstrategyuse == true){Value.Set(12);}}
				
				if (EMA(1)[0] == EMA(4)[0])
				 {DrawDot("AARCNR10"+barcounter.ToString(), true, 0, Close [0] + TickSize, nr12color);
					if (wordingon == true){DrawText("nr10text"+ CurrentBar, nr10text, 0, Close[0] + (seperation+5) *TickSize, Color.Black);}
				if (zstrategyuse == true){Value.Set(1);}}
				
			}
        }

        #region Properties
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries Plot0
        {
            get { return Values[0]; }
        }

        [Description("Count back Period for the narrowest range")]
        [Category("Parameters")]
        public int Period
        {
            get { return period; }
            set { period = Math.Max(3, value); }
        }
		
		[Description("What you want to see displayed as a text label.")]
        [GridCategory("Parameters")]
        public string Nr10text
        {
            get { return nr10text; }
            set { nr10text = value; }
        }
		
		[Description("AARCNR10 Color")]
		[XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
		[Category("Visual")]
		[Gui.Design.DisplayName("Color")]
		public Color NR12Color
		{
			get { return nr12color; }
			set { nr12color = value; }
		}
		
		[Description("Distance between hi / lo and maker")]
        [GridCategory("Parameters")]
        public int Seperation
        {
            get { return seperation; }
            set { seperation = Math.Max(1, value); }
        }
		
		[Description("True = Text displayed on screen")]
        [GridCategory("Parameters")]
        public bool Wordingon
        {
            get { return wordingon; }
            set { wordingon = value; }
        }
		[Description("True = Use within a strategy Buy 11 Sell 12 Neutral 1")]
        [GridCategory("Parameters")]
        public bool Zstrategyuse
        {
            get { return zstrategyuse; }
            set { zstrategyuse = value; }
        }
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private AARCNR10[] cacheAARCNR10 = null;

        private static AARCNR10 checkAARCNR10 = new AARCNR10();

        /// <summary>
        /// Highlight bar if it is the narrowest.
        /// </summary>
        /// <returns></returns>
        public AARCNR10 AARCNR10(string nr10text, int period, int seperation, bool wordingon, bool zstrategyuse)
        {
            return AARCNR10(Input, nr10text, period, seperation, wordingon, zstrategyuse);
        }

        /// <summary>
        /// Highlight bar if it is the narrowest.
        /// </summary>
        /// <returns></returns>
        public AARCNR10 AARCNR10(Data.IDataSeries input, string nr10text, int period, int seperation, bool wordingon, bool zstrategyuse)
        {
            if (cacheAARCNR10 != null)
                for (int idx = 0; idx < cacheAARCNR10.Length; idx++)
                    if (cacheAARCNR10[idx].Nr10text == nr10text && cacheAARCNR10[idx].Period == period && cacheAARCNR10[idx].Seperation == seperation && cacheAARCNR10[idx].Wordingon == wordingon && cacheAARCNR10[idx].Zstrategyuse == zstrategyuse && cacheAARCNR10[idx].EqualsInput(input))
                        return cacheAARCNR10[idx];

            lock (checkAARCNR10)
            {
                checkAARCNR10.Nr10text = nr10text;
                nr10text = checkAARCNR10.Nr10text;
                checkAARCNR10.Period = period;
                period = checkAARCNR10.Period;
                checkAARCNR10.Seperation = seperation;
                seperation = checkAARCNR10.Seperation;
                checkAARCNR10.Wordingon = wordingon;
                wordingon = checkAARCNR10.Wordingon;
                checkAARCNR10.Zstrategyuse = zstrategyuse;
                zstrategyuse = checkAARCNR10.Zstrategyuse;

                if (cacheAARCNR10 != null)
                    for (int idx = 0; idx < cacheAARCNR10.Length; idx++)
                        if (cacheAARCNR10[idx].Nr10text == nr10text && cacheAARCNR10[idx].Period == period && cacheAARCNR10[idx].Seperation == seperation && cacheAARCNR10[idx].Wordingon == wordingon && cacheAARCNR10[idx].Zstrategyuse == zstrategyuse && cacheAARCNR10[idx].EqualsInput(input))
                            return cacheAARCNR10[idx];

                AARCNR10 indicator = new AARCNR10();
                indicator.BarsRequired = BarsRequired;
                indicator.CalculateOnBarClose = CalculateOnBarClose;
#if NT7
                indicator.ForceMaximumBarsLookBack256 = ForceMaximumBarsLookBack256;
                indicator.MaximumBarsLookBack = MaximumBarsLookBack;
#endif
                indicator.Input = input;
                indicator.Nr10text = nr10text;
                indicator.Period = period;
                indicator.Seperation = seperation;
                indicator.Wordingon = wordingon;
                indicator.Zstrategyuse = zstrategyuse;
                Indicators.Add(indicator);
                indicator.SetUp();

                AARCNR10[] tmp = new AARCNR10[cacheAARCNR10 == null ? 1 : cacheAARCNR10.Length + 1];
                if (cacheAARCNR10 != null)
                    cacheAARCNR10.CopyTo(tmp, 0);
                tmp[tmp.Length - 1] = indicator;
                cacheAARCNR10 = tmp;
                return indicator;
            }
        }
    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// Highlight bar if it is the narrowest.
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.AARCNR10 AARCNR10(string nr10text, int period, int seperation, bool wordingon, bool zstrategyuse)
        {
            return _indicator.AARCNR10(Input, nr10text, period, seperation, wordingon, zstrategyuse);
        }

        /// <summary>
        /// Highlight bar if it is the narrowest.
        /// </summary>
        /// <returns></returns>
        public Indicator.AARCNR10 AARCNR10(Data.IDataSeries input, string nr10text, int period, int seperation, bool wordingon, bool zstrategyuse)
        {
            return _indicator.AARCNR10(input, nr10text, period, seperation, wordingon, zstrategyuse);
        }
    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// Highlight bar if it is the narrowest.
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.AARCNR10 AARCNR10(string nr10text, int period, int seperation, bool wordingon, bool zstrategyuse)
        {
            return _indicator.AARCNR10(Input, nr10text, period, seperation, wordingon, zstrategyuse);
        }

        /// <summary>
        /// Highlight bar if it is the narrowest.
        /// </summary>
        /// <returns></returns>
        public Indicator.AARCNR10 AARCNR10(Data.IDataSeries input, string nr10text, int period, int seperation, bool wordingon, bool zstrategyuse)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.AARCNR10(input, nr10text, period, seperation, wordingon, zstrategyuse);
        }
    }
}
#endregion
