#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using System.Windows.Forms;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// Enter the description of your new custom indicator here AARCSQ1001 version:B
    /// </summary>
    [Description("Enter the description of your new custom indicator here")]
    public class AARCSQ1001 : Indicator
    {
        #region Variables
        // Wizard generated variables
            private int ema1 = 5; // Default setting for Ema1
           
			private int entry = 40; // Default setting for Entry
			private int exit = 120; // Default setting for Exit
			private int x = 2; // Default setting for counter
			private int trend = 150; // Default setting for Ema trend
			private double zone = 2.5; // Default setting for squeeze zone in percentage
			private Color upcolor = Color.LightGreen; // Default setting for Upcolor
			private Color downcolor = Color.LightPink; // Default setting for Downcolor
			private int seperation = 150; // Default setting for seperation
			private bool 	playAlert = false;
			private string 	buyalert = "BuyingSQ1000.wav";
			private string 	sellalert = "SellingSQ1000.wav";
			private bool zstrategyuse = false;
			private double zonep = 0; // Default setting for squeeze zone in percentage
			
        // User defined variables (add any user defined variables below)
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
			VendorLicense("RaefonTrading", "AARCSQ1001", "raefontrading.com", "info@raefontrading.com");
            
            Add(new Plot(Color.FromKnownColor(KnownColor.PaleGreen), PlotStyle.Line, "PlotEma1"));            
			Add(new Plot(new Pen(Color.FromKnownColor(KnownColor.DarkBlue),3), PlotStyle.Line, "Plottarget"));
			Add(new Plot(new Pen(Color.FromKnownColor(KnownColor.DarkSeaGreen),3), PlotStyle.Line, "Plotentry"));
			Add(new Plot(new Pen(Color.FromKnownColor(KnownColor.Black),3), PlotStyle.Line, "PlotEma7"));
						
            Overlay	= true;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
			
			
        {
			zonep =  (Close[0]* zone ) ;
			
            
			if (zstrategyuse == true){Value.Set(0);}  // Sets value to 0 when not in strategy use
			
			
			 if (EMA(Ema1)[0] + -zonep/5 * TickSize < EMA(Ema1*2)[0]
                && EMA(Ema1*2)[0] + -zonep/5 * TickSize < EMA(Ema1*4)[0]
                && EMA(Ema1*4)[0] + -zonep/5 * TickSize < EMA(Ema1*8)[0]
                && EMA(Ema1*8)[0] + -zonep * TickSize < EMA(Ema1)[0]
				&& (Rising(EMA(Trend)))
				
				
				
				)
			
			
			{
			 x = 1;
            PlotEma1.Set(EMA(Ema1)[0]);           
            
			Plottarget.Set(MAX(High, Exit)[0]);
			Plotentry.Set(MIN(Low, Entry)[0]);
			PlotEma7.Set(EMA(Trend)[0]);
	
			DrawArrowUp("My up arrow" + CurrentBar, false, 0, Low[0] + -Seperation * TickSize, upcolor);
			
				if (playAlert == true) 	{	PlaySound(Buyalert);}
				if (zstrategyuse == true){Value.Set(11);}
			}
			
			
			if (EMA(Ema1)[0]+  zonep/5 * TickSize > EMA(Ema1*2)[0]
                && EMA(Ema1*2)[0] +  zonep/5 * TickSize > EMA(Ema1*4)[0]
                && EMA(Ema1*4)[0] +  zonep/5 * TickSize > EMA(Ema1*8)[0]
                && EMA(Ema1*8)[0] +  zonep * TickSize > EMA(Ema1)[0]
				&& (Falling(EMA(Trend)))


				
				)
			
			
			{
			 x = 3;
            PlotEma1.Set(EMA(Ema1)[0]);
            
			Plottarget.Set(MIN(Low, Exit)[0]);
			Plotentry.Set(MAX(High, Entry)[0]);
			PlotEma7.Set(EMA(Trend)[0]);
	
			DrawArrowDown("My down arrow" + CurrentBar, false, 0, High[0] + Seperation * TickSize, downcolor);
			
				if (playAlert == true)  { PlaySound(sellalert);	}
				if (zstrategyuse == true){Value.Set(12);}
				
			}
			
			else 
			{ x = 2; }
								
        }

        #region Properties
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries PlotEma1
        {
            get { return Values[0]; }
        }        
		[Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries Plottarget
        {
            get { return Values[1]; }
        }
		[Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries Plotentry
        {
            get { return Values[2]; }
        }
		[Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries PlotEma7
        {
            get { return Values[3]; }
        }
        [Description("Very Important Key ema to use as a compression zone builder. Usually a low number 1 - 12 can be higher depending on time frame using")]
        [GridCategory("Parameters")]
        public int Ema1
        {
            get { return ema1; }
            set { ema1 = Math.Max(1, value); }
        }

        
		[Description("Trailing hi lo period to use as a general entry level")]
        [GridCategory("Parameters")]
        public int Entry
        {
            get { return entry; }
            set { entry = Math.Max(1, value); }
        }
		[Description("Trailing hi lo period to use as a general exit level")]
        [GridCategory("Parameters")]
        public int Exit
        {
            get { return exit; }
            set { exit = Math.Max(1, value); }
        }
		[Description("Risng / falling ema to use as a trend")]
        [GridCategory("Parameters")]
        public int Trend
        {
            get { return trend; }
            set { trend = Math.Max(1, value); }
        }
		[Description("Size of compresion zone / consolidation in percent of closing price can be decimal % i.e. 0.25 = 1/4% 0r 1.5 = 1 1/2% etc")]
        [GridCategory("Parameters")]
        public double Zone
        {
            get { return zone; }
            set { zone = Math.Max(0, value); }
        }
		[Description("Colour for buy signals")]
        [Category("Visual")]
		[Gui.Design.DisplayName("Color")]
		[XmlIgnore()]	
        public Color Upcolor
        {
            get { return upcolor; }
            set { upcolor = value; }
        }
		[Description("Colour for sell signals")]
        [Category("Visual")]
		[Gui.Design.DisplayName("Color")]
		[XmlIgnore()]	
        public Color Downcolor
        {
            get { return downcolor; }
            set { downcolor = value; }
        }
		[Description("How many pips of seperation above / below to plot marker and text ")]
        [GridCategory("Parameters")]
        public int Seperation
        {
            get { return seperation; }
            set { seperation = Math.Max(1, value); }
        }
		[Description("Play Alert - sound file in C drive sounds if you havent saved the sound file use False")]
        [Category("Sounds")]
        [Gui.Design.DisplayName("01. Play Alert?")]
        public bool PlayAlert
        {
            get { return playAlert; }
            set { playAlert = value; }
        }
		[Description("File Name for long alert")]
        [Category("Sounds")]
        [Gui.Design.DisplayName("02. Long Alert")]
        public string Buyalert
        {
            get { return buyalert; }
            set { buyalert = value; }
        }
		[Description("File Name for short alert")]
        [Category("Sounds")]
        [Gui.Design.DisplayName("03. short Alert")]
		
		public string Sellalert
			
        {
			get { return sellalert; }
            set { sellalert = value; }
        }
		
		[Description("If true To use within a strategy values are buy 11 sell 12")]
        [GridCategory("Parameters")]
        public bool Zstrategyuse
        {
            get { return zstrategyuse; }
            set { zstrategyuse = value; }
        }
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private AARCSQ1001[] cacheAARCSQ1001 = null;

        private static AARCSQ1001 checkAARCSQ1001 = new AARCSQ1001();

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public AARCSQ1001 AARCSQ1001(int ema1, int entry, int exit, int seperation, int trend, double zone, bool zstrategyuse)
        {
            return AARCSQ1001(Input, ema1, entry, exit, seperation, trend, zone, zstrategyuse);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public AARCSQ1001 AARCSQ1001(Data.IDataSeries input, int ema1, int entry, int exit, int seperation, int trend, double zone, bool zstrategyuse)
        {
            if (cacheAARCSQ1001 != null)
                for (int idx = 0; idx < cacheAARCSQ1001.Length; idx++)
                    if (cacheAARCSQ1001[idx].Ema1 == ema1 && cacheAARCSQ1001[idx].Entry == entry && cacheAARCSQ1001[idx].Exit == exit && cacheAARCSQ1001[idx].Seperation == seperation && cacheAARCSQ1001[idx].Trend == trend && Math.Abs(cacheAARCSQ1001[idx].Zone - zone) <= double.Epsilon && cacheAARCSQ1001[idx].Zstrategyuse == zstrategyuse && cacheAARCSQ1001[idx].EqualsInput(input))
                        return cacheAARCSQ1001[idx];

            lock (checkAARCSQ1001)
            {
                checkAARCSQ1001.Ema1 = ema1;
                ema1 = checkAARCSQ1001.Ema1;
                checkAARCSQ1001.Entry = entry;
                entry = checkAARCSQ1001.Entry;
                checkAARCSQ1001.Exit = exit;
                exit = checkAARCSQ1001.Exit;
                checkAARCSQ1001.Seperation = seperation;
                seperation = checkAARCSQ1001.Seperation;
                checkAARCSQ1001.Trend = trend;
                trend = checkAARCSQ1001.Trend;
                checkAARCSQ1001.Zone = zone;
                zone = checkAARCSQ1001.Zone;
                checkAARCSQ1001.Zstrategyuse = zstrategyuse;
                zstrategyuse = checkAARCSQ1001.Zstrategyuse;

                if (cacheAARCSQ1001 != null)
                    for (int idx = 0; idx < cacheAARCSQ1001.Length; idx++)
                        if (cacheAARCSQ1001[idx].Ema1 == ema1 && cacheAARCSQ1001[idx].Entry == entry && cacheAARCSQ1001[idx].Exit == exit && cacheAARCSQ1001[idx].Seperation == seperation && cacheAARCSQ1001[idx].Trend == trend && Math.Abs(cacheAARCSQ1001[idx].Zone - zone) <= double.Epsilon && cacheAARCSQ1001[idx].Zstrategyuse == zstrategyuse && cacheAARCSQ1001[idx].EqualsInput(input))
                            return cacheAARCSQ1001[idx];

                AARCSQ1001 indicator = new AARCSQ1001();
                indicator.BarsRequired = BarsRequired;
                indicator.CalculateOnBarClose = CalculateOnBarClose;
#if NT7
                indicator.ForceMaximumBarsLookBack256 = ForceMaximumBarsLookBack256;
                indicator.MaximumBarsLookBack = MaximumBarsLookBack;
#endif
                indicator.Input = input;
                indicator.Ema1 = ema1;
                indicator.Entry = entry;
                indicator.Exit = exit;
                indicator.Seperation = seperation;
                indicator.Trend = trend;
                indicator.Zone = zone;
                indicator.Zstrategyuse = zstrategyuse;
                Indicators.Add(indicator);
                indicator.SetUp();

                AARCSQ1001[] tmp = new AARCSQ1001[cacheAARCSQ1001 == null ? 1 : cacheAARCSQ1001.Length + 1];
                if (cacheAARCSQ1001 != null)
                    cacheAARCSQ1001.CopyTo(tmp, 0);
                tmp[tmp.Length - 1] = indicator;
                cacheAARCSQ1001 = tmp;
                return indicator;
            }
        }
    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.AARCSQ1001 AARCSQ1001(int ema1, int entry, int exit, int seperation, int trend, double zone, bool zstrategyuse)
        {
            return _indicator.AARCSQ1001(Input, ema1, entry, exit, seperation, trend, zone, zstrategyuse);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public Indicator.AARCSQ1001 AARCSQ1001(Data.IDataSeries input, int ema1, int entry, int exit, int seperation, int trend, double zone, bool zstrategyuse)
        {
            return _indicator.AARCSQ1001(input, ema1, entry, exit, seperation, trend, zone, zstrategyuse);
        }
    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.AARCSQ1001 AARCSQ1001(int ema1, int entry, int exit, int seperation, int trend, double zone, bool zstrategyuse)
        {
            return _indicator.AARCSQ1001(Input, ema1, entry, exit, seperation, trend, zone, zstrategyuse);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public Indicator.AARCSQ1001 AARCSQ1001(Data.IDataSeries input, int ema1, int entry, int exit, int seperation, int trend, double zone, bool zstrategyuse)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.AARCSQ1001(input, ema1, entry, exit, seperation, trend, zone, zstrategyuse);
        }
    }
}
#endregion
